@@ -108,7 +108,7 @@ extern _CRTIMP void __cdecl exit(int);
    and redifinition of Windows system defs, also removes requirement of
    pretty much any standard windows header from this file */
 
-#if (_MSC_VER >= 800) || defined(_STDCALL_SUPPORTED)
+#if (_MSC_VER >= 800) || defined(_STDCALL_SUPPORTED) || defined(__CYGWIN32__)
 #	define GLUTAPIENTRY __stdcall
 #else
 #	define GLUTAPIENTRY
@@ -199,7 +199,7 @@ WGLAPI int   GLAPIENTRY SetPixelFormat(HDC,int,const PIXELFORMATDESCRIPTOR *);
 #  define GLUTCALLBACK
 #  define GLUTAPI extern
 /* Prototype exit for the non-Win32 case (see above). */
-extern void exit(int);
+/*extern void exit(int);  this screws up gcc -ansi -pedantic! */
 #endif
 
 
