@@ -24,13 +24,15 @@
 #define GLUT_BUILDING_LIB  /* Building the GLUT library itself. */
 #include <GL/glut.h>
 
-#if defined( MESA ) && defined( _WIN32 )
+#if defined(MESA) && defined(_WIN32) && !defined(__CYGWIN32__)
 #include <gl/mesa_wgl.h>
 #endif
 
 #ifndef _WIN32
 /* added by BrianP: */
+#ifndef APIENTRY
 #define APIENTRY GLAPIENTRY
+#endif
 #define __cdecl GLAPIENTRY
 #define CDECL GLAPIENTRY
 #endif
@@ -71,7 +73,7 @@ extern int sys$gettim(struct timeval *);
 #endif
 #else
 #include <sys/types.h>
-#if !defined(_WIN32)
+#if !defined(_WIN32) || defined(__CYGWIN32__)
 #include <sys/time.h>
 #else
 #include <winsock.h>
